/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

// Ametys Namespace
Ext.namespace('org.ametys.cms.tree');

org.ametys.cms.tree.DataSourceXmlLoader = Ext.extend(org.ametys.tree.XmlTreeLoader, {});

org.ametys.cms.tree.DataSourceXmlLoader.prototype.processResponse = function(response, node, callback) 
{
	this._nodeTags = {};
	
	this._nodeTags['dataSourceType'] = '';
	this._nodeTags['datasource'] = '';
	this._nodeTags['query'] = '';
	
	org.ametys.cms.tree.DataSourceXmlLoader.superclass.processResponse.call(this, response, node, callback);
}

org.ametys.cms.tree.DataSourceXmlLoader.prototype.processAttributes = function(attr)
{
	org.ametys.cms.tree.DataSourceXmlLoader.superclass.processAttributes.call(this, attr);
	
	if (attr.tagName == 'dataSourceType')
	{
        attr.text = attr.id;
        attr.dataSourceType = attr.id;
        attr.id = 'dataSourceType://' + attr.id;
        attr.type = 'dataSourceType';
        attr.leafSort = false; // attribute for sorting
        
        var type = attr.dataSourceType.toLowerCase();
        
        attr.icon = getPluginResourcesUrl('datainclusion') + '/img/content/' + type + '-connections.png';
        attr.iconCls = 'datainclusion-tree-node-icon';
        
        attr.expanded = true;
        attr.loaded = true;
	}
	else if (attr.tagName == 'datasource')
	{
        attr.text = attr.name;
        attr.dataSourceType = attr.type;
        attr.nodeName = attr.id;
        attr.id = 'datasource://' + attr.id;
        attr.type = 'datasource';
        attr.leafSort = false; // attribute for sorting
        
        var type = attr.dataSourceType.toLowerCase();
        
        attr.icon = getPluginResourcesUrl('datainclusion') + '/img/content/' + type + '-connection.png';
        attr.iconCls = 'datainclusion-tree-node-icon';
        
        attr.expanded = true;
        attr.loaded = true;
	}
	else if (attr.tagName = 'query')
	{
        attr.text = attr.name;
        attr.dataSourceType = attr.type;
        attr.nodeName = attr.id;
        attr.id = 'query://' + attr.id;
        var resultType = attr.resultType.toLowerCase();
        attr.type = 'query';
        attr.leafSort = false; // attribute for sorting
        
        attr.icon = getPluginResourcesUrl('datainclusion') + '/img/content/query-' + resultType + '.png';
        attr.iconCls = 'datainclusion-tree-node-icon';
        attr.leaf = true;
	}
	
}

org.ametys.cms.tree.DataSourceXmlLoader.prototype.createNode = function(node) 
{
	var attr = {
		tagName: node.tagName,
		leaf: node.childNodes.length == 0
	};

	Ext.each(node.attributes, function(a) {
		attr[a.nodeName] = a.nodeValue;
	});
	
	this._currentXMLNode = node;
	this.processAttributes(attr);
	delete this._currentXMLNode;
	
	if (this.baseAttrs)
    {
        Ext.applyIf(attr, this.baseAttrs);
    }
    if (this.applyLoader !== false)
    {
		attr.loader = this;
    }
    if (typeof attr.uiProvider == 'string')
    {
       attr.uiProvider = this.uiProviders[attr.uiProvider] || eval(attr.uiProvider);
    }
    
    if (attr.tagName == "dataSourceType" || attr.tagName == "datasource")
    {
    	return new Ext.tree.AsyncTreeNode(attr);
    }
    else
    {
    	return new Ext.tree.TreeNode(attr);
    }
}
